# HistoricalApi

All URIs are relative to *https://api.discoversnoop.com*

Method | HTTP request | Description
------------- | ------------- | -------------
[**categoriesGet**](HistoricalApi.md#categoriesGet) | **GET** /categories | Get historical stats for categories
[**categoryGet**](HistoricalApi.md#categoryGet) | **GET** /category | Get history for category ID
[**domainGet**](HistoricalApi.md#domainGet) | **GET** /domain | Get history for domain name
[**domainsGet**](HistoricalApi.md#domainsGet) | **GET** /domains | Get historical stats for domains
[**pageGet**](HistoricalApi.md#pageGet) | **GET** /page | Get page history for URL
[**pagesGet**](HistoricalApi.md#pagesGet) | **GET** /pages | Get historical stats for pages

<a name="categoriesGet"></a>
# **categoriesGet**
> List&lt;Categories&gt; categoriesGet(country, subcountry, fromDate, toDate, keywordFilter, lines, offset)

Get historical stats for categories

### Example
```java
// Import classes:
//import io.swagger.client.ApiClient;
//import io.swagger.client.ApiException;
//import io.swagger.client.Configuration;
//import io.swagger.client.auth.*;
//import io.swagger.client.api.HistoricalApi;

ApiClient defaultClient = Configuration.getDefaultApiClient();


HistoricalApi apiInstance = new HistoricalApi();
String country = "country_example"; // String | ISO_3166 country code in 2 letters
String subcountry = "subcountry_example"; // String | state code
String fromDate = "fromDate_example"; // String | Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience)
String toDate = "toDate_example"; // String | Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience)
String keywordFilter = "keywordFilter_example"; // String | Filter answers to cateogry names containing a particular keyword
Integer lines = 50; // Integer | Get X results (max in one request is 10K please use offset paginated results if you need more)
Integer offset = 0; // Integer | Get paginated results from X offset
try {
    List<Categories> result = apiInstance.categoriesGet(country, subcountry, fromDate, toDate, keywordFilter, lines, offset);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling HistoricalApi#categoriesGet");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **country** | **String**| ISO_3166 country code in 2 letters |
 **subcountry** | **String**| state code | [optional]
 **fromDate** | **String**| Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional]
 **toDate** | **String**| Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional]
 **keywordFilter** | **String**| Filter answers to cateogry names containing a particular keyword | [optional]
 **lines** | **Integer**| Get X results (max in one request is 10K please use offset paginated results if you need more) | [optional] [default to 50]
 **offset** | **Integer**| Get paginated results from X offset | [optional] [default to 0]

### Return type

[**List&lt;Categories&gt;**](Categories.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="categoryGet"></a>
# **categoryGet**
> List&lt;Category&gt; categoryGet(id, country, subcountry, fromDate, toDate)

Get history for category ID

### Example
```java
// Import classes:
//import io.swagger.client.ApiClient;
//import io.swagger.client.ApiException;
//import io.swagger.client.Configuration;
//import io.swagger.client.auth.*;
//import io.swagger.client.api.HistoricalApi;

ApiClient defaultClient = Configuration.getDefaultApiClient();


HistoricalApi apiInstance = new HistoricalApi();
String id = "id_example"; // String | category id
String country = "country_example"; // String | ISO_3166 country code in 2 letters
String subcountry = "subcountry_example"; // String | state code
String fromDate = "fromDate_example"; // String | Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience)
String toDate = "toDate_example"; // String | Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience)
try {
    List<Category> result = apiInstance.categoryGet(id, country, subcountry, fromDate, toDate);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling HistoricalApi#categoryGet");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **id** | **String**| category id |
 **country** | **String**| ISO_3166 country code in 2 letters |
 **subcountry** | **String**| state code | [optional]
 **fromDate** | **String**| Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional]
 **toDate** | **String**| Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional]

### Return type

[**List&lt;Category&gt;**](Category.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="domainGet"></a>
# **domainGet**
> List&lt;Domain&gt; domainGet(domain, country, subcountry, fromDate, toDate)

Get history for domain name

### Example
```java
// Import classes:
//import io.swagger.client.ApiClient;
//import io.swagger.client.ApiException;
//import io.swagger.client.Configuration;
//import io.swagger.client.auth.*;
//import io.swagger.client.api.HistoricalApi;

ApiClient defaultClient = Configuration.getDefaultApiClient();


HistoricalApi apiInstance = new HistoricalApi();
String domain = "domain_example"; // String | domain name (no subdomain allowed)
String country = "country_example"; // String | ISO_3166 country code in 2 letters
String subcountry = "subcountry_example"; // String | state code
String fromDate = "fromDate_example"; // String | Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience)
String toDate = "toDate_example"; // String | Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience)
try {
    List<Domain> result = apiInstance.domainGet(domain, country, subcountry, fromDate, toDate);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling HistoricalApi#domainGet");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **domain** | **String**| domain name (no subdomain allowed) |
 **country** | **String**| ISO_3166 country code in 2 letters |
 **subcountry** | **String**| state code | [optional]
 **fromDate** | **String**| Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional]
 **toDate** | **String**| Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional]

### Return type

[**List&lt;Domain&gt;**](Domain.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="domainsGet"></a>
# **domainsGet**
> List&lt;Domains&gt; domainsGet(country, subcountry, fromDate, toDate, urlFilter, lines, offset)

Get historical stats for domains

### Example
```java
// Import classes:
//import io.swagger.client.ApiClient;
//import io.swagger.client.ApiException;
//import io.swagger.client.Configuration;
//import io.swagger.client.auth.*;
//import io.swagger.client.api.HistoricalApi;

ApiClient defaultClient = Configuration.getDefaultApiClient();


HistoricalApi apiInstance = new HistoricalApi();
String country = "country_example"; // String | ISO_3166 country code in 2 letters
String subcountry = "subcountry_example"; // String | state code
String fromDate = "fromDate_example"; // String | Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience)
String toDate = "toDate_example"; // String | Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience)
String urlFilter = "urlFilter_example"; // String | Filter answers to domains including a specified string
Integer lines = 50; // Integer | Get X results (max in one request is 10K please use offset paginated results if you need more)
Integer offset = 0; // Integer | Get paginated results from X offset
try {
    List<Domains> result = apiInstance.domainsGet(country, subcountry, fromDate, toDate, urlFilter, lines, offset);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling HistoricalApi#domainsGet");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **country** | **String**| ISO_3166 country code in 2 letters |
 **subcountry** | **String**| state code | [optional]
 **fromDate** | **String**| Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional]
 **toDate** | **String**| Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional]
 **urlFilter** | **String**| Filter answers to domains including a specified string | [optional]
 **lines** | **Integer**| Get X results (max in one request is 10K please use offset paginated results if you need more) | [optional] [default to 50]
 **offset** | **Integer**| Get paginated results from X offset | [optional] [default to 0]

### Return type

[**List&lt;Domains&gt;**](Domains.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="pageGet"></a>
# **pageGet**
> List&lt;Page&gt; pageGet(url, country, subcountry, fromDate, toDate)

Get page history for URL

### Example
```java
// Import classes:
//import io.swagger.client.ApiClient;
//import io.swagger.client.ApiException;
//import io.swagger.client.Configuration;
//import io.swagger.client.auth.*;
//import io.swagger.client.api.HistoricalApi;

ApiClient defaultClient = Configuration.getDefaultApiClient();


HistoricalApi apiInstance = new HistoricalApi();
String url = "url_example"; // String | Fully qualified page url. URL needs to be URL encoded
String country = "country_example"; // String | ISO_3166 country code in 2 letters
String subcountry = "subcountry_example"; // String | state code
String fromDate = "fromDate_example"; // String | Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience)
String toDate = "toDate_example"; // String | Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience)
try {
    List<Page> result = apiInstance.pageGet(url, country, subcountry, fromDate, toDate);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling HistoricalApi#pageGet");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **url** | **String**| Fully qualified page url. URL needs to be URL encoded |
 **country** | **String**| ISO_3166 country code in 2 letters |
 **subcountry** | **String**| state code | [optional]
 **fromDate** | **String**| Datas from YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional]
 **toDate** | **String**| Datas to YYYY-MM-DD (if not provided, datas will adjust to page audience) | [optional]

### Return type

[**List&lt;Page&gt;**](Page.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="pagesGet"></a>
# **pagesGet**
> List&lt;Pages&gt; pagesGet(presetFilter, fromDate, toDate, country, subcountry, domainFilter, urlFilter, categoryFilter, keywordFilter, lines, offset)

Get historical stats for pages

### Example
```java
// Import classes:
//import io.swagger.client.ApiClient;
//import io.swagger.client.ApiException;
//import io.swagger.client.Configuration;
//import io.swagger.client.auth.*;
//import io.swagger.client.api.HistoricalApi;

ApiClient defaultClient = Configuration.getDefaultApiClient();


HistoricalApi apiInstance = new HistoricalApi();
Integer presetFilter = 56; // Integer | Apply preset filters => 0 no filter 1 no newsstories 2 only newsstories 3 only sapphire 4 only moonstone 5 sapphire and moonstone combined 6 sapphire or moonstone
String fromDate = "fromDate_example"; // String | Datas from YYYY-MM-DD (if not provided, last 30 days)
String toDate = "toDate_example"; // String | Datas to YYYY-MM-DD (if not provided, last 30 days)
String country = "country_example"; // String | ISO_3166 country code in 2 letters (if not provided  worldwide)
String subcountry = "subcountry_example"; // String | state code
String domainFilter = "domainFilter_example"; // String | Filter answers to pages of a designated domain name
String urlFilter = "urlFilter_example"; // String | Filter answers to pages URL including a specified string
Integer categoryFilter = 56; // Integer | Filter answers to a specific page category
String keywordFilter = "keywordFilter_example"; // String | Filter answers to pages titles containing a particular keyword
Integer lines = 50; // Integer | Get X results (max in one request is 50 please use offset paginated results if you need more)
Integer offset = 0; // Integer | Get paginated results from X offset
try {
    List<Pages> result = apiInstance.pagesGet(presetFilter, fromDate, toDate, country, subcountry, domainFilter, urlFilter, categoryFilter, keywordFilter, lines, offset);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling HistoricalApi#pagesGet");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **presetFilter** | **Integer**| Apply preset filters &#x3D;&gt; 0 no filter 1 no newsstories 2 only newsstories 3 only sapphire 4 only moonstone 5 sapphire and moonstone combined 6 sapphire or moonstone |
 **fromDate** | **String**| Datas from YYYY-MM-DD (if not provided, last 30 days) | [optional]
 **toDate** | **String**| Datas to YYYY-MM-DD (if not provided, last 30 days) | [optional]
 **country** | **String**| ISO_3166 country code in 2 letters (if not provided  worldwide) | [optional]
 **subcountry** | **String**| state code | [optional]
 **domainFilter** | **String**| Filter answers to pages of a designated domain name | [optional]
 **urlFilter** | **String**| Filter answers to pages URL including a specified string | [optional]
 **categoryFilter** | **Integer**| Filter answers to a specific page category | [optional]
 **keywordFilter** | **String**| Filter answers to pages titles containing a particular keyword | [optional]
 **lines** | **Integer**| Get X results (max in one request is 50 please use offset paginated results if you need more) | [optional] [default to 50]
 **offset** | **Integer**| Get paginated results from X offset | [optional] [default to 0]

### Return type

[**List&lt;Pages&gt;**](Pages.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

