# LiveApi

All URIs are relative to *https://api.discoversnoop.com*

Method | HTTP request | Description
------------- | ------------- | -------------
[**livecategoriesGet**](LiveApi.md#livecategoriesGet) | **GET** /livecategories | Get livedata stats for categories
[**livedomainsGet**](LiveApi.md#livedomainsGet) | **GET** /livedomains | Get livedata stats for domains
[**livepagesGet**](LiveApi.md#livepagesGet) | **GET** /livepages | Get livedata stats for pages

<a name="livecategoriesGet"></a>
# **livecategoriesGet**
> List&lt;Categories&gt; livecategoriesGet(country, subcountry, hours, keywordFilter, languageFilter, lines, offset)

Get livedata stats for categories

### Example
```java
// Import classes:
//import io.swagger.client.ApiClient;
//import io.swagger.client.ApiException;
//import io.swagger.client.Configuration;
//import io.swagger.client.auth.*;
//import io.swagger.client.api.LiveApi;

ApiClient defaultClient = Configuration.getDefaultApiClient();


LiveApi apiInstance = new LiveApi();
String country = "country_example"; // String | ISO_3166 country code in 2 letters
String subcountry = "subcountry_example"; // String | state code
Integer hours = 56; // Integer | Get results for last x hours
String keywordFilter = "keywordFilter_example"; // String | Filter answers to category names containing a particular keyword
String languageFilter = "languageFilter_example"; // String | Filter answers to pages in specific user language
Integer lines = 50; // Integer | Get X results (max in one request is 10K please use offset paginated results if you need more)
Integer offset = 0; // Integer | Get paginated results from X offset
try {
    List<Categories> result = apiInstance.livecategoriesGet(country, subcountry, hours, keywordFilter, languageFilter, lines, offset);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling LiveApi#livecategoriesGet");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **country** | **String**| ISO_3166 country code in 2 letters |
 **subcountry** | **String**| state code | [optional]
 **hours** | **Integer**| Get results for last x hours | [optional]
 **keywordFilter** | **String**| Filter answers to category names containing a particular keyword | [optional]
 **languageFilter** | **String**| Filter answers to pages in specific user language | [optional]
 **lines** | **Integer**| Get X results (max in one request is 10K please use offset paginated results if you need more) | [optional] [default to 50]
 **offset** | **Integer**| Get paginated results from X offset | [optional] [default to 0]

### Return type

[**List&lt;Categories&gt;**](Categories.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="livedomainsGet"></a>
# **livedomainsGet**
> List&lt;Domains&gt; livedomainsGet(country, subcountry, urlFilter, hours, lines, languageFilter, offset)

Get livedata stats for domains

### Example
```java
// Import classes:
//import io.swagger.client.ApiClient;
//import io.swagger.client.ApiException;
//import io.swagger.client.Configuration;
//import io.swagger.client.auth.*;
//import io.swagger.client.api.LiveApi;

ApiClient defaultClient = Configuration.getDefaultApiClient();


LiveApi apiInstance = new LiveApi();
String country = "country_example"; // String | ISO_3166 country code in 2 letters
String subcountry = "subcountry_example"; // String | state code
String urlFilter = "urlFilter_example"; // String | Filter answers to domains including a specified string
Integer hours = 56; // Integer | Get results for last x hours
Integer lines = 50; // Integer | Get X results (max in one request is 10K please use offset paginated results if you need more)
String languageFilter = "languageFilter_example"; // String | Filter answers to pages in specific user language
Integer offset = 0; // Integer | Get paginated results from X offset
try {
    List<Domains> result = apiInstance.livedomainsGet(country, subcountry, urlFilter, hours, lines, languageFilter, offset);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling LiveApi#livedomainsGet");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **country** | **String**| ISO_3166 country code in 2 letters |
 **subcountry** | **String**| state code | [optional]
 **urlFilter** | **String**| Filter answers to domains including a specified string | [optional]
 **hours** | **Integer**| Get results for last x hours | [optional]
 **lines** | **Integer**| Get X results (max in one request is 10K please use offset paginated results if you need more) | [optional] [default to 50]
 **languageFilter** | **String**| Filter answers to pages in specific user language | [optional]
 **offset** | **Integer**| Get paginated results from X offset | [optional] [default to 0]

### Return type

[**List&lt;Domains&gt;**](Domains.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

<a name="livepagesGet"></a>
# **livepagesGet**
> List&lt;Pages&gt; livepagesGet(country, presetFilter, subcountry, hours, onlyNew, domainFilter, keywordFilter, urlFilter, categoryFilter, languageFilter, lines, offset)

Get livedata stats for pages

### Example
```java
// Import classes:
//import io.swagger.client.ApiClient;
//import io.swagger.client.ApiException;
//import io.swagger.client.Configuration;
//import io.swagger.client.auth.*;
//import io.swagger.client.api.LiveApi;

ApiClient defaultClient = Configuration.getDefaultApiClient();


LiveApi apiInstance = new LiveApi();
String country = "country_example"; // String | ISO_3166 country code in 2 letters
Integer presetFilter = 56; // Integer | Apply preset filters => 0 no filter 1 no newsstories 2 only newsstories 3 only sapphire 4 only moonstone 5 sapphire and moonstone combined 6 sapphire or moonstone
String subcountry = "subcountry_example"; // String | state code
Integer hours = 56; // Integer | Get results for last x hours
Integer onlyNew = 0; // Integer | Get only pages first seen in the reporting period if set on 1
String domainFilter = "domainFilter_example"; // String | Filter answers to pages of a designated domain name
String keywordFilter = "keywordFilter_example"; // String | Filter answers to pages titles containing a particular keyword
String urlFilter = "urlFilter_example"; // String | Filter answers to pages URL including a specified string
Integer categoryFilter = 56; // Integer | Filter answers to pages of a designated category id
String languageFilter = "languageFilter_example"; // String | Filter answers to pages in specific user language
Integer lines = 50; // Integer | Get X results (max in one request is 50 please use offset paginated results if you need more)
Integer offset = 0; // Integer | Get paginated results from X offset
try {
    List<Pages> result = apiInstance.livepagesGet(country, presetFilter, subcountry, hours, onlyNew, domainFilter, keywordFilter, urlFilter, categoryFilter, languageFilter, lines, offset);
    System.out.println(result);
} catch (ApiException e) {
    System.err.println("Exception when calling LiveApi#livepagesGet");
    e.printStackTrace();
}
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **country** | **String**| ISO_3166 country code in 2 letters |
 **presetFilter** | **Integer**| Apply preset filters &#x3D;&gt; 0 no filter 1 no newsstories 2 only newsstories 3 only sapphire 4 only moonstone 5 sapphire and moonstone combined 6 sapphire or moonstone |
 **subcountry** | **String**| state code | [optional]
 **hours** | **Integer**| Get results for last x hours | [optional]
 **onlyNew** | **Integer**| Get only pages first seen in the reporting period if set on 1 | [optional] [default to 0]
 **domainFilter** | **String**| Filter answers to pages of a designated domain name | [optional]
 **keywordFilter** | **String**| Filter answers to pages titles containing a particular keyword | [optional]
 **urlFilter** | **String**| Filter answers to pages URL including a specified string | [optional]
 **categoryFilter** | **Integer**| Filter answers to pages of a designated category id | [optional]
 **languageFilter** | **String**| Filter answers to pages in specific user language | [optional]
 **lines** | **Integer**| Get X results (max in one request is 50 please use offset paginated results if you need more) | [optional] [default to 50]
 **offset** | **Integer**| Get paginated results from X offset | [optional] [default to 0]

### Return type

[**List&lt;Pages&gt;**](Pages.md)

### Authorization

[bearerAuth](../README.md#bearerAuth)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

